searchNodes=[{"doc":"The event manager dispatches events to subscribers and adds some syntactic sugar as well as helpers on top of elixir's Registry.It can also help reduce code complexity and lib coupling.","ref":"EventManager.html","title":"EventManager","type":"module"},{"doc":"Dispatch my event to every registered subscriber.The dispatch function will call all Modules/functions that have subscribed to the dispatch event. You can also add some data useful for managing the event in callbacks.For example, if you want to dispatch an event when a new user is created, it could be nice to send the user in the event payload.E.g.iex&gt; user = %{id: 1234, name: &quot;Foo Bar&quot;, email: &quot;foo@bar.com&quot;} iex&gt; EventManager.dispatch(&quot;user_created&quot;, %{user: user}) iex&gt; EventManager.dispatch(&quot;user_created&quot;, user)Basically you can send whatever you want as a payload.","ref":"EventManager.html#dispatch/2","title":"EventManager.dispatch/2","type":"function"},{"doc":"Return the registry name used by EventManager.","ref":"EventManager.html#get_registry_name/0","title":"EventManager.get_registry_name/0","type":"function"},{"doc":"Start the registry and register static subscriptions.opts accepts ::apps: The application name that you want to use in the EventManager.E.giex&gt; EventManager.start_link(apps: [MyApp])","ref":"EventManager.html#start_link/1","title":"EventManager.start_link/1","type":"function"},{"doc":"Start subscriptions.This function is automatically called if you use EventManager.start_link/1, but it's nice to know that you can call it manually depending on your needs.E.g.iex&gt; EventManager.start_link([MyApp])","ref":"EventManager.html#start_subscriptions/1","title":"EventManager.start_subscriptions/1","type":"function"},{"doc":"Subscribe to an event.You can subscribe to an event by using the @subscribe attribute. To use it, first you must use EventManager.Handler.E.g. defmodule MyApp do use EventManager.Handler @subscribe &quot;event_1&quot; def on_event_1(pid, payload) do # business logic end @subscribe event: &quot;event_2&quot;, callback: &quot;my_callback&quot; def my_callback(pid, payload) do # business logic end endpid is the id of the process that subscribes to the event. payload is the data that has been dispatched.You can also subscribe dynamically (during runtime) using this function directly.E.giex&gt; EventManager.subscribe(&quot;event_name&quot;, {MyApp, :callback}) :ok","ref":"EventManager.html#subscribe/2","title":"EventManager.subscribe/2","type":"function"},{"doc":"Unsubsribe from the specified event.It can be very useful for async systems that are used by multiple PIDs for example. It's higly recommended that you only use it for dynamic subscriptions (see EventManager.subscribe/2)It will only unsubscribe the event for the calling PID.E.g.iex&gt; EventManager.unsubscribe(&quot;my_event_name&quot;)","ref":"EventManager.html#unsubscribe/1","title":"EventManager.unsubscribe/1","type":"function"},{"doc":"An event message is defined with the following format :%{event: &quot;event_name&quot;, payload: &quot;data&quot;}The payload data can be of any type (integer, float, Map ...).","ref":"EventManager.Handler.html","title":"EventManager.Handler","type":"behaviour"},{"doc":"","ref":"EventManager.Handler.html#map_events/1","title":"EventManager.Handler.map_events/1","type":"function"},{"doc":"","ref":"EventManager.Handler.html#modules/1","title":"EventManager.Handler.modules/1","type":"function"},{"doc":"","ref":"EventManager.Handler.html#subscriptions/0","title":"EventManager.Handler.subscriptions/0","type":"macro"},{"doc":"","ref":"EventManager.Handler.html#c:subscriptions/0","title":"EventManager.Handler.subscriptions/0","type":"callback"},{"doc":"EventManagerOfficial documentation: hexdocs.The event manager helps you manage subscriptions to specific events. Thanks to this lib, you'll be able to easily reduce coupling.Inspired by the EventDispatcher package from Symfony Framework and adapted for functionnal programming.","ref":"readme.html","title":"EventManager","type":"extras"},{"doc":"def deps do [ {:event_manager, &quot;~&gt; 0.1.0&quot;} ] endBefore using the lib you first have to register it using EventManager.start_link/1, which also accepts a keyword opts for options. Inside your options, you can specify all the apps that can use the @subscribe attribute.Here's an example using a Supervisor:children = [%{ id: EventManager, start: {EventManager, :start_link, [[apps: [:manager]]]} }] opts = [strategy: :one_for_one, name: Manager.Supervisor] Supervisor.start_link(children, opts)","ref":"readme.html#installation","title":"EventManager - Installation","type":"extras"},{"doc":"In this quickstart we'll define a mailing system that sends an email when a new user is created. In this example, we assume you know Ecto basics and how to define a user schema.First, let's create a module that will handle the user_created event, that will be dispatched when a new user is created.This module will send an email when the user_created event is dispatched.defmodule Mail do use EventManager.Handler # ... other functions @subscribe &quot;user_created&quot; def on_user_created(_pid, user) do Mail.send_welcome(user) end endThe on_user_created function will be called each time we dispatch the event user_created. We assume that user will be sent as the event's parameter.When using @subsribe eventname the system will call the function `on\#{event_name}` as the default callback.Then, we'll create a User module with the create/1 function. This function will dispatch a user_created event when the user has been inserted into the database.defmodule User do # ... ecto schema and changeset (according to ecto) def create(user_params) do user = %__MODULE__{} |&gt; changeset(user_params) |&gt; MyApp.Repo.insert() with {:ok, _} &lt;- user do EventManager.dispatch(&quot;user_created&quot;, user) end user end end","ref":"readme.html#quickstart","title":"EventManager - Quickstart","type":"extras"},{"doc":"There are 2 ways to register a subscriber.Dynamically EventManager.subscribe(&quot;event_name&quot;, {MyApp, :callback})Staticly@subscribe &quot;event_name&quot; # or @subscribe event: &quot;event_name&quot;, callback: :function_nameIn case you only use @subscribe &quot;event_name&quot;, the callback's name will be on_event_name.Modules that use static subscriptions must use the module EventManager.Handler. Using this module will define a function called subscriptions/0 that returns the list of subscribed events. It will also register your callback automatically for the specified event.","ref":"readme.html#subscribers","title":"EventManager - Subscribers","type":"extras"}]